# factest

A Fantistic Factor Analysising Tools For Quant

股票因子分析工具

## 安装

### 安装factest

```bash
pip install factest
```

**注意: 默认不会安装jqdatasdk和talib两个包**

### 安装jqdatasdk

```bash
pip install jqdatasdk
```

### 安装talib

#### 方式一 官网安装

- https://mrjbq7.github.io/ta-lib/install.html

#### 方式二 通过whl文件安装

- 下载whl文件(**仅限windows, python3.7**)

链接：https://pan.baidu.com/s/1zIar16uUeGWGQMM7d0zWdg 
提取码：zg54 

- pip 安装

```bash
pip install TA_Lib-0.4.19-cp37-cp37m-win_amd64.whl
```

## 使用

详细见examples



